@@ -40,9 +40,7 @@ in this Software without prior written authorization from the X Consortium.
 #include <errno.h>
 #include <X11/StringDefs.h>
 #include <X11/Xos.h>
-#ifndef X_NOT_STDC_ENV
 #include <stdlib.h>
-#endif
 #include <X11/Xfuncs.h>
 #include <X11/Xaw3d/XawInit.h>
 #include <X11/Xaw3d/AsciiSrcP.h>
@@ -116,17 +114,7 @@ static String MyStrncpy(char *, char *, int);
 static String StorePiecesInString(AsciiSrcObject);
 static Boolean SetValues(Widget, Widget, Widget, ArgList, Cardinal *);
 static Boolean WriteToFile(_Xconst _XtString, _Xconst _XtString);
-#ifdef X_NOT_STDC_ENV
-extern int errno;
-#endif
 
-#ifdef X_NOT_POSIX
-#define Off_t long
-#define Size_t unsigned int
-#else
-#define Off_t off_t
-#define Size_t size_t
-#endif
 
 #define superclass		(&textSrcClassRec)
 AsciiSrcClassRec asciiSrcClassRec = {
@@ -1044,7 +1032,7 @@ InitStringOrFile(AsciiSrcObject src, Boolean newString)
 
     if (!src->ascii_src.is_tempfile) {
 	if ((file = fopen(src->ascii_src.string, open_mode)) != 0) {
-	    (void) fseek(file, (Off_t)0, 2);
+	    (void) fseek(file, 0, SEEK_END);
 	    src->ascii_src.length = (XawTextPosition) ftell(file);
 	    return file;
 	} else {
@@ -1074,9 +1062,9 @@ LoadPieces(AsciiSrcObject src, FILE * file, char * string)
       local_str = XtMalloc((unsigned) (src->ascii_src.length + 1)
 			   * sizeof(unsigned char));
       if (src->ascii_src.length != 0) {
-	fseek(file, (Off_t)0, 0);
-	src->ascii_src.length = fread(local_str, (Size_t)sizeof(unsigned char),
-				      (Size_t)src->ascii_src.length, file);
+	fseek(file, 0, SEEK_SET);
+	src->ascii_src.length = fread(local_str, sizeof(unsigned char),
+				      (size_t)src->ascii_src.length, file);
 	if (src->ascii_src.length <= 0)
 	  XtErrorMsg("readError", "asciiSourceCreate", "XawError",
 		     "fread returned error.", NULL, NULL);
